# InterruptionResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**space_id** | **str** |  | [optional] 
**title** | **str** |  | [optional] 
**created** | **datetime** |  | [optional] 
**is_pending** | **bool** |  | [optional] 
**form** | [**Form**](Form.md) |  | [optional] 
**related_document_ids** | **list[str]** |  | [optional] 
**responsible_team_ids** | **list[str]** |  | [optional] 
**responsible_user_id** | **str** |  | [optional] 
**can_take_responsibility** | **bool** |  | [optional] 
**has_responsibility** | **bool** |  | [optional] 
**task_id** | **str** |  | [optional] 
**correlation_id** | **str** |  | [optional] 
**is_linked_to_other_interruption** | **bool** |  | [optional] 
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


